@@ -103,7 +103,7 @@ class DeHyperPol(Recording):
 
         # Converting back to ms
         for name_timing in ["ton", "tmid", "toff"]:
-            self.timing_index_to_ms(name_timing, t)
+            self.index_to_ms(name_timing, t)
         self.tend = len(t) * self.dt
 
     def generate(self):
